<?php

namespace Support\Support\Http\Controllers;

use App\Http\Controllers\AdminController as AdminController;
use Former;
use Support\Support\Http\Requests\SupportAdminRequest;
use Support\Support\Interfaces\SupportRepositoryInterface;
use Response;

/**
 * Admin controller class.
 */
class SupportAdminController extends AdminController
{
    /**
     * Initialize support controller.
     *
     * @param type SupportRepositoryInterface $support
     *
     * @return type
     */
    public function __construct(SupportRepositoryInterface $support)
    {
        $this->model = $support;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(SupportAdminRequest $request)
    {
        if ($request->wantsJson()) {
            $array = $this->model->json();
            foreach ($array as $key => $row) {
                $array[$key] = array_only($row, config('support.support.listfields'));
            }

            return ['data' => $array];
        }

        $this->theme->prependTitle(trans('support::support.names').' :: ');

        return $this->theme->of('support::admin.support.index')->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(SupportAdminRequest $request, $id)
    {
        $support = $this->model->find($id);

        if (empty($support)) {
            if ($request->wantsJson()) {
                return [];
            }

            return view('support::admin.support.new');
        }

        if ($request->wantsJson()) {
            return $support;
        }

        Former::populate($support);

        return view('support::admin.support.show', compact('support'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(SupportAdminRequest $request)
    {
        $support = $this->model->findOrNew(0);
        Former::populate($support);

        return view('support::admin.support.create', compact('support'));
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(SupportAdminRequest $request)
    {
        try {
            $attributes = $request->all();
            $support = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('support::support.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(SupportAdminRequest $request, $id)
    {
        $support = $this->model->find($id);

        Former::populate($support);

        return view('support::admin.support.edit', compact('support'));
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(SupportAdminRequest $request, $id)
    {
        try {
            $attributes = $request->all();
            $support = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('support::support.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(SupportAdminRequest $request, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('support::support.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
